@@ -11,6 +11,7 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.subprocess_manager.flow import RunAction
 
 from libreflow import baseflow
+from libreflow.baseflow.file import CreateDefaultFilesAction
 
 from libreflow.utils.b3d import wrap_python_expr
 from libreflow.utils.flow import get_context_value
@@ -18,7 +19,19 @@ from libreflow.utils.flow import get_context_value
 from .file import FileSystemMap
 
 
+class CreateDeptDefaultFilesAction(CreateDefaultFilesAction):
+
+    _department = flow.Parent()
+
+    def get_target_groups(self):
+        return [self._department.name()]
+
+    def get_file_map(self):
+        return self._department.files
+
+
 class Department(baseflow.departments.Department):
+    
     _short_name = flow.Param(None)
     _file_prefix = flow.Computed(cached=True)
     _shot = flow.Parent(2)
@@ -32,6 +45,8 @@ class Department(baseflow.departments.Department):
         hidden=True,
         editable=False,
     )
+
+    create_default_files = flow.Child(CreateDeptDefaultFilesAction)
     
     def compute_child_value(self, child_value):
         if child_value is self.path:
@@ -944,6 +959,7 @@ class BuildRenderScene(BuildBlenderScene):
 
 
 class CompDepartment(Department):
+
     _short_name = flow.Param("comp")
 
     build_render_scene = flow.Child(BuildRenderScene)
@@ -956,13 +972,22 @@ class CompDepartment(Department):
 
 
 class MiscDepartment(Department):
+
     _short_name = flow.Param("misc")
 
+
+class BackgroundDepartment(Department):
+
+    _short_name = flow.Param('bckg')
+
+
 class ShotDepartments(flow.Object):
-    layout = flow.Child(LayoutDepartment).ui(expanded=False)
-    animation = flow.Child(AnimationDepartment).ui(expanded=False)
+
+    layout      = flow.Child(LayoutDepartment).ui(expanded=False)
+    animation   = flow.Child(AnimationDepartment).ui(expanded=False)
     compositing = flow.Child(CompDepartment).ui(expanded=False)
-    misc = flow.Child(MiscDepartment).ui(expanded=False)
+    background  = flow.Child(BackgroundDepartment).ui(expanded=False)
+    misc        = flow.Child(MiscDepartment).ui(expanded=False)
 
 
 class Shot(baseflow.film.Shot):
